@@ -39,3 +39,5 @@ SAML_ATTR_MAP = []
 SAML_BASE_DIRECTORY = None
 
 SAML_DESTINATION_HOST = None
+SAML_DESTINATION_HTTPS = None
+SAML_DESTINATION_PORT = None
